extension EnumByNameOrDefault<TEnum extends Enum> on Iterable<TEnum> {
  /// Finds the enum value in this list with name [name] or returns the [defaultVal] specified.
  ///
  /// Goes through this collection looking for an enum with
  /// name [name], as reported by [EnumName.name].
  ///
  /// Returns the first value with the given name or the [defaultVal] provided.
  TEnum byNameOrDefault(String name, {required TEnum defaultVal}) {
    for (var value in this) {
      if (value.name == name) return value;
    }
    return defaultVal;
  }
}
