import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

Future<void> showAlertMessage(BuildContext context, String title, String body, { String buttonText = "OK"}) {
  return showAlert(context, title, [Text(body)], buttonText: buttonText);
}

Future<void> showAlert(BuildContext context, String title, List<Widget> body, { String buttonText = "OK"}) async {
  return showDialog<void>(
    context: context,
    barrierDismissible: false, // user must tap button!
    builder: (BuildContext context) {
      return AlertDialog(
        title: Text(title),
        content: SingleChildScrollView(
          child: ListBody(
            children: body,
          ),
        ),
        actions: <Widget>[
          TextButton(
            child: Text(buttonText),
            onPressed: () {
              Navigator.of(context).pop();
            },
          ),
        ],
      );
    },
  );
}


Future<void> showNativeAlertMessage(BuildContext context, String title, String body, { String buttonText = "OK"}) {
  return showNativeAlert(context, title, [Text(body)], buttonText: buttonText);
}

Future<void> showNativeAlert(BuildContext context, String title, List<Widget> body, { String buttonText = "OK"}) async {
  if (Theme.of(context).platform == TargetPlatform.iOS) {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return CupertinoAlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: ListBody(
              children: body,
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(buttonText),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  } else {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: ListBody(
              children: body,
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(buttonText),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  }
}

Future<bool?> showNativeYesNoAlert(BuildContext context, String title, String message, {String yesButtonText = "YES", String noButtonText = "NO", bool allowModalClose = false}) {
  if (Theme.of(context).platform == TargetPlatform.iOS) {
    // Use CupertinoAlertDialog for iOS
    return showCupertinoDialog<bool>(
      context: context,
      barrierDismissible: allowModalClose,
      builder: (context) {
        return CupertinoAlertDialog(
          title: Text(title),
          content: Text(message),
          actions: <Widget>[
            CupertinoDialogAction(
              onPressed: () {
                Navigator.of(context).pop(false);
              },
              child: Text(noButtonText),
            ),
            CupertinoDialogAction(
              onPressed: () {
                Navigator.of(context).pop(true);
              },
              child: Text(yesButtonText),
            ),
          ],
        );
      },
    );
  } else {
    // Use Material AlertDialog for Android
    return showDialog<bool>(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: Text(title),
          content: Text(message),
          actions: <Widget>[
            TextButton(
              onPressed: () {
                Navigator.of(context).pop(false);
              },
              child: Text(noButtonText),
            ),
            TextButton(
              onPressed: () {
                Navigator.of(context).pop(true);
              },
              child: Text(yesButtonText),
            ),
          ],
        );
      },
    );
  }
}